from django.conf import settings
from django.template import Context, Template, TemplateSyntaxError
from django.test import TestCase


class GoogleAnalytics(TestCase):

    def setUp(self):
        self.orig = settings.GANALYTICS_TRACKING_CODE
        self.render = lambda t: Template(t).render(Context())

    def test_can_load_google_analytics_template_tags(self):
        self.assertEqual(self.render('{% load ganalytics %}'), '')

    def test_render_fails_without_including_template_tag(self):
        self.assertRaises(TemplateSyntaxError, self.render, '{% ganalytics %}')

    def test_render_doesnt_render_anything_if_no_setting_exists(self):
        del settings.GANALYTICS_TRACKING_CODE
        self.assertEqual(self.render('{% load ganalytics %}{% ganalytics %}'), '')

    def test_render_doesnt_render_anything_if_the_setting_exists_but_is_not_valid(self):
        settings.GANALYTICS_TRACKING_CODE = ''
        self.assertEqual(self.render('{% load ganalytics %}{% ganalytics %}'), '')

        settings.GANALYTICS_TRACKING_CODE = None
        self.assertEqual(self.render('{% load ganalytics %}{% ganalytics %}'), '')

    def test_render_returns_javascript_code_if_setting_exists(self):
        settings.GANALYTICS_TRACKING_CODE = 'UA-12345678-90'
        self.assertIn('UA-12345678-90', self.render('{% load ganalytics %}{% ganalytics %}'))

    def tearDown(self):
        settings.GANALYTICS_TRACKING_CODE = self.orig



from os.path import abspath, dirname, join, normpath

from setuptools import setup


setup(

    # Basic package information:
    name = 'django-ganalytics',
    version = '0.3',
    packages = ['ganalytics'],

    # Packaging options:
    zip_safe = False,
    include_package_data = True,

    # Package dependencies:
    install_requires = ['Django>=1.3.1'],

    # Metadata for PyPI:
    author = 'Randall Degges',
    author_email = 'rdegges@gmail.com',
    license = 'UNLICENSE',
    url = 'https://github.com/rdegges/django-ganalytics',
    keywords = 'django google analytics',
    description = 'Simple Google Analytics integration for Django.',
    long_description = open(normpath(join(dirname(abspath(__file__)),
        'README.md'))).read()

)



"""A simple Django templatetag that renders Google Analytics asynchronous
Javascript code.
"""

from django.conf import settings
from django import template
from django.template import Context
from django.template.loader import get_template


register = template.Library()


@register.simple_tag
def ganalytics():
    """Render Google Analytics tracking code if, and only if, the user has
    defined a ``GANALYTICS_TRACKING_CODE`` setting.
    """
    if hasattr(settings, 'GANALYTICS_TRACKING_CODE') and settings.GANALYTICS_TRACKING_CODE:
        context = Context({'GANALYTICS_TRACKING_CODE': settings.GANALYTICS_TRACKING_CODE})
        return get_template('ganalytics/ganalytics.js').render(context)
    return ''
